@@ -114,6 +114,7 @@ class Installer
     protected $ignorePlatformReqs = false;
     protected $preferStable = false;
     protected $preferLowest = false;
+    protected $skipSuggest = false;
     /**
      * Array of package names/globs flagged for update
      *
@@ -228,7 +229,7 @@ class Installer
         }
 
         // output suggestions if we're in dev mode
-        if ($this->devMode) {
+        if ($this->devMode && !$this->skipSuggest) {
             $this->suggestedPackagesReporter->output($installedRepo);
         }
 
@@ -296,6 +297,11 @@ class Installer
                 $this->eventDispatcher->dispatchScript($eventName, $this->devMode);
             }
 
+            // force binaries re-generation in case they are missing
+            foreach ($localRepo->getPackages() as $package) {
+                $this->installationManager->ensureBinariesPresence($package);
+            }
+
             $vendorDir = $this->config->get('vendor-dir');
             if (is_dir($vendorDir)) {
                 // suppress errors as this fails sometimes on OSX for no apparent reason
@@ -619,7 +625,7 @@ class Installer
         // but as it is not persisted on disk we use a loader/dumper
         // to reload it in memory
         $localRepo = new InstalledArrayRepository(array());
-        $loader = new ArrayLoader();
+        $loader = new ArrayLoader(null, true);
         $dumper = new ArrayDumper();
         foreach ($tempLocalRepo->getCanonicalPackages() as $pkg) {
             $localRepo->addPackage($loader->load($dumper->dump($pkg)));
@@ -1131,6 +1137,10 @@ class Installer
 
     private function updateInstallReferences(PackageInterface $package, $reference)
     {
+        if (!$reference) {
+            return;
+        }
+
         $package->setSourceReference($reference);
         $package->setDistReference($reference);
 
@@ -1600,6 +1610,19 @@ class Installer
         return $this;
     }
 
+    /**
+     * Should suggestions be skipped?
+     *
+     * @param  bool      $skipSuggest
+     * @return Installer
+     */
+    public function setSkipSuggest($skipSuggest = true)
+    {
+        $this->skipSuggest = (boolean) $skipSuggest;
+
+        return $this;
+    }
+
     /**
      * Disables plugins.
      *
